---

slug: /array-data-type-overview
---

# Array data type overview

seekdb supports the array data type (ARRAY), which can be used to store and process multiple elements of the same type.

The array element types supported by the current version of seekdb are as follows:

* Integer types: `TINYINT`, `SMALLINT`, `INT`/`INTEGER`, and `BIGINT`.

* Floating-point types: `FLOAT` and `DOUBLE`.

* String type: `VARCHAR`.

The following points describe the array data type:

* The array data type is a commonly used data type in OLAP scenarios. It is mainly used to store and process multiple data elements of the same type.

* When describing a multivalued attribute of an entity (for example, a product belongs to multiple categories, a user has multiple tags, or a sensor has multiple measurements), the array data type can be used to naturally express such relationships.

* During data analysis, the array data type is often used to determine whether a specific value exists in an array.

The following points describe the limitations of the array data type:

* The array data type does not support setting default values.

In addition to providing the array data type, seekdb also provides functions for array data. For more information, see [Array functions](https://en.oceanbase.com/docs/common-oceanbase-database-10000000001974941).